[−][src]Trait specs_task::TaskFactory
Implemented by all nodes of a TaskGraph. Has a blanket impl that should work for most
TaskComponents.
Implemented by all nodes of a TaskGraph. Has a blanket impl that should work for most
TaskComponents.
fn create_task(&self, task_maker: &TaskMaker) -> Entityimpl<'a, T: 'static + Clone + TaskComponent<'a>> TaskFactory for T[src]fn create_task(&self, task_maker: &TaskMaker) -> Entity[src]